pub struct TestAttr {
pub key: String,
pub value: String,
}Expand description
A flexible test attribute descriptor used by all components.
By default, components will render data-testid="...", but callers can
override the attribute key if they need a different name.
Fields
key: Stringvalue: StringImplementations